]> git.ipfire.org Git - people/ms/u-boot.git/commitdiff
env: Rename some other getenv()-related functions
authorSimon Glass <sjg@chromium.org>
Thu, 3 Aug 2017 18:22:15 +0000 (12:22 -0600)
committerTom Rini <trini@konsulko.com>
Wed, 16 Aug 2017 12:31:11 +0000 (08:31 -0400)
We are now using an env_ prefix for environment functions. Rename these
other functions as well, for consistency:

   getenv_vlan()
   getenv_bootm_size()
   getenv_bootm_low()
   getenv_bootm_mapsize()
   env_get_default()

Suggested-by: Wolfgang Denk <wd@denx.de>
Signed-off-by: Simon Glass <sjg@chromium.org>
41 files changed:
arch/powerpc/lib/bootm.c
board/Arcturus/ucp1020/ucp1020.c
board/freescale/b4860qds/b4860qds.c
board/freescale/bsc9131rdb/bsc9131rdb.c
board/freescale/bsc9132qds/bsc9132qds.c
board/freescale/c29xpcie/c29xpcie.c
board/freescale/corenet_ds/corenet_ds.c
board/freescale/mpc8572ds/mpc8572ds.c
board/freescale/p1010rdb/p1010rdb.c
board/freescale/p1022ds/p1022ds.c
board/freescale/p1023rdb/p1023rdb.c
board/freescale/p1_p2_rdb_pc/p1_p2_rdb_pc.c
board/freescale/p1_twr/p1_twr.c
board/freescale/p2041rdb/p2041rdb.c
board/freescale/t102xqds/t102xqds.c
board/freescale/t102xrdb/t102xrdb.c
board/freescale/t1040qds/t1040qds.c
board/freescale/t104xrdb/t104xrdb.c
board/freescale/t208xqds/t208xqds.c
board/freescale/t208xrdb/t208xrdb.c
board/freescale/t4qds/t4240emu.c
board/freescale/t4qds/t4240qds.c
board/freescale/t4rdb/t4240rdb.c
board/gdsys/p1022/controlcenterd.c
board/keymile/kmp204x/kmp204x.c
board/varisys/cyrus/cyrus.c
cmd/elf.c
cmd/mtdparts.c
cmd/net.c
common/bootm.c
common/image-fdt.c
common/image.c
drivers/net/netconsole.c
env/common.c
env/flags.c
include/common.h
include/environment.h
include/image.h
include/net.h
net/link_local.c
net/net.c

index 932c38ab4c2bcd2e342bb98e04602ba91a44f60b..b9ae24dc98b6bc334060fe429586d33eeb5c0678 100644 (file)
@@ -86,7 +86,7 @@ static void boot_jump_linux(bootm_headers_t *images)
                debug ("   Booting using OF flat tree...\n");
                WATCHDOG_RESET ();
                (*kernel) ((bd_t *)of_flat_tree, 0, 0, EPAPR_MAGIC,
-                          getenv_bootm_mapsize(), 0, 0);
+                          env_get_bootm_mapsize(), 0, 0);
                /* does not return */
        } else
 #endif
@@ -121,8 +121,8 @@ void arch_lmb_reserve(struct lmb *lmb)
        phys_size_t bootm_size;
        ulong size, sp, bootmap_base;
 
-       bootmap_base = getenv_bootm_low();
-       bootm_size = getenv_bootm_size();
+       bootmap_base = env_get_bootm_low();
+       bootm_size = env_get_bootm_size();
 
 #ifdef DEBUG
        if (((u64)bootmap_base + bootm_size) >
@@ -340,6 +340,6 @@ void boot_jump_vxworks(bootm_headers_t *images)
 
        ((void (*)(void *, ulong, ulong, ulong,
                ulong, ulong, ulong))images->ep)(images->ft_addr,
-               0, 0, EPAPR_MAGIC, getenv_bootm_mapsize(), 0, 0);
+               0, 0, EPAPR_MAGIC, env_get_bootm_mapsize(), 0, 0);
 }
 #endif
index dfdaf0441c98ab7822419e6c3a2bee516ac6564a..3f786a20148b59feb939fd9403cab2cf6faf8f24 100644 (file)
@@ -307,8 +307,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 1fea91b3b5e955f732b3e50239c8dd88d7185c5a..5d872fdfd9b99b2c23adf75ae0f61a21a5172ea2 100644 (file)
@@ -1197,8 +1197,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index fb8bb39d87e303ceb041046db54002c3ed35fe09..c642e88a097b05770c92808c785674a0000e184b 100644 (file)
@@ -65,8 +65,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 #ifdef CONFIG_FDT_FIXUP_PARTITIONS
index a7772c4bf4c29eecad2b996706d37719560977ae..ed0b453e54b922faaee09d54c17f553632c28937 100644 (file)
@@ -370,8 +370,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        #if defined(CONFIG_PCI)
        FT_FSL_PCI_SETUP;
index 45f463f01f38134ca38e0793f3b83170b95e1f5f..23901a4f96adc555bc965347029d97d5e4f0fa6f 100644 (file)
@@ -138,8 +138,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
 #if defined(CONFIG_PCI)
        FT_FSL_PCI_SETUP;
index 93e1258295617b815605d1a97d043f39283ce3bf..132650c938744c62e3e13c842d84a936cb70691e 100644 (file)
@@ -191,8 +191,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index ed6836a93027b8035d119d85db692f1e77403778..93d54f5c4aa2dcabb8ec0b8dee09906798335e29 100644 (file)
@@ -239,8 +239,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 65bb575a9643836b613047e8375d65adf21ed214..aa04e993c460124a23dc858960dc563e761d2e26 100644 (file)
@@ -453,8 +453,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
 #if defined(CONFIG_PCI)
        FT_FSL_PCI_SETUP;
index 345feac0b2941ece20fe5f491cff95b2034a8d85..bf493262d07442a2a8a14bba918e160670b97021 100644 (file)
@@ -339,8 +339,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 04517226033d4d254583ee6a90e01620dfc8b457..ccda82412536020736cf47fe7a5ad4daa486db26 100644 (file)
@@ -137,8 +137,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 9ae38ce1154303bc377ee0d8d9217827d9d63b50..31c8ed9ae17e3ce1188ef20d81d37419cb49b487 100644 (file)
@@ -439,8 +439,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index f54a6ff8dc7260a9b7847c715d81155aa1db1a80..02c89998cb4d23c18152c2e3033c3c1b90f4967e 100644 (file)
@@ -268,8 +268,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 21fb66f184a4c0e65eac2c577fbd9d1211dc9f8d..78ee74770c3f377e9b8ba9aad6267709ef024efd 100644 (file)
@@ -219,8 +219,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 1b2f6b248754284aac94b319fc866ed8a6591f98..20374baf48c136c0949a928f81d425c5fbac10a1 100644 (file)
@@ -363,8 +363,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index f370f72baa6a7ed0173534c82338d2ea5848f805..8885a546fa3a5a6dfd79853f8d85e4ee3c37896c 100644 (file)
@@ -186,8 +186,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 5466fbf5f661bd136bf7b1a925fd9cf3a17493ab..a36997b48cb43cf98578d79e321d6239ba9bd57f 100644 (file)
@@ -245,8 +245,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index d4c3d4dcb420680d8a462c14063a169a6334cbfb..2818cdf2745fd9ae427387d177e061c534d47a01 100644 (file)
@@ -132,8 +132,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 26093ea9d265a23fc9a8a8c0edbc00a53950b084..ed3d3f4b71d07147f89c00bd03fd2f2d0e3d3c9e 100644 (file)
@@ -451,8 +451,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 1ab05ec9fd4300c2dabf87ad8b1452fa26d59fe9..619495e6abcdf61ac1a546fac8680fed69b42f09 100644 (file)
@@ -118,8 +118,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 35ad19e045b163130ed37363d97dc9a7d78fb76e..7136acafeae180f71323e08e96d44e638b5775b3 100644 (file)
@@ -70,8 +70,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 2bdd6a349d7991af5e9f0ea2f9218ada5a6fca7a..7b71b541fda29609f5a7dbb85646f54ad4b5aa94 100644 (file)
@@ -684,8 +684,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index bdd6f4ef49a74dd6d47d0ef26c11a84809377a37..f511706b9f8047b538f1d2640e075ba2220bdf82 100644 (file)
@@ -97,8 +97,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 24e58cbf0013e4d5762febdde987668a3dd2ef98..9fb814d8c7c0de99fc4de43bcab5e20073f81778 100644 (file)
@@ -335,8 +335,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 671bddfa1cdf309867d7cb36a029d8200cb86c46..8c9d6b167d4744dd62520973510f445676a78b00 100644 (file)
@@ -271,8 +271,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 74f4473877e27855974c8f77449ce5b36917d59c..30f518abe89469f9f82ddea7e2bb46c71df4828a 100644 (file)
@@ -87,8 +87,8 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        ft_cpu_setup(blob, bd);
 
-       base = getenv_bootm_low();
-       size = getenv_bootm_size();
+       base = env_get_bootm_low();
+       size = env_get_bootm_size();
 
        fdt_fixup_memory(blob, (u64)base, (u64)size);
 
index 51dac03170669746c8e5ce24c56ddfa0a395691a..5745a389dae7038267fddd316605a6dce8d9a3dc 100644 (file)
--- a/cmd/elf.c
+++ b/cmd/elf.c
@@ -300,7 +300,7 @@ int do_bootvx(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
                                ptr += sprintf(build_buf + ptr, "e=%s", tmp);
                                tmp = env_get("netmask");
                                if (tmp) {
-                                       u32 mask = getenv_ip("netmask").s_addr;
+                                       u32 mask = env_get_ip("netmask").s_addr;
                                        ptr += sprintf(build_buf + ptr,
                                                       ":%08x ", ntohl(mask));
                                } else {
index a72668119deae5bb3532d172417b17cddec69001..615aa7459af3b68967fd8eae483e126724c583d6 100644 (file)
@@ -1533,7 +1533,7 @@ static int spread_partitions(void)
  * @param buf temporary buffer pointer MTDPARTS_MAXLEN long
  * @return mtdparts variable string, NULL if not found
  */
-static const char *getenv_mtdparts(char *buf)
+static const char *env_get_mtdparts(char *buf)
 {
        if (gd->flags & GD_FLG_ENV_READY)
                return env_get("mtdparts");
@@ -1565,7 +1565,7 @@ static int parse_mtdparts(const char *const mtdparts)
        }
 
        /* re-read 'mtdparts' variable, mtd_devices_init may be updating env */
-       p = getenv_mtdparts(tmp_parts);
+       p = env_get_mtdparts(tmp_parts);
        if (!p)
                p = mtdparts;
 
@@ -1742,7 +1742,7 @@ int mtdparts_init(void)
 
        /* get variables */
        ids = env_get("mtdids");
-       parts = getenv_mtdparts(tmp_parts);
+       parts = env_get_mtdparts(tmp_parts);
        current_partition = env_get("partition");
 
        /* save it for later parsing, cannot rely on current partition pointer
index 3b77c8952f173409b42391cd166830a25f55a862..d7c776aacf3d0745f5c9f0e34cf7958082a63896 100644 (file)
--- a/net/net.c
+++ b/net/net.c
@@ -1536,7 +1536,7 @@ ushort string_to_vlan(const char *s)
        return htons(id);
 }
 
-ushort getenv_vlan(char *var)
+ushort env_get_vlan(char *var)
 {
        return string_to_vlan(env_get(var));
 }
--- a/cmd/net.c
+++ b/cmd/net.c
@@ -331,7 +331,7 @@ int do_sntp(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
        char *toff;
 
        if (argc < 2) {
-               net_ntp_server = getenv_ip("ntpserverip");
+               net_ntp_server = env_get_ip("ntpserverip");
                if (net_ntp_server.s_addr == 0) {
                        printf("ntpserverip not set\n");
                        return CMD_RET_FAILURE;
index 08563540670c4349d3915091702ffcaa9eb10a34..32b3ea8e2d093a203ae67f73ee03a207ba39f212 100644 (file)
@@ -55,8 +55,8 @@ static void boot_start_lmb(bootm_headers_t *images)
 
        lmb_init(&images->lmb);
 
-       mem_start = getenv_bootm_low();
-       mem_size = getenv_bootm_size();
+       mem_start = env_get_bootm_low();
+       mem_size = env_get_bootm_size();
 
        lmb_add(&images->lmb, (phys_addr_t)mem_start, mem_size);
 
index 2c499467c32499dc10082a38f479c08739457494..da4d0070815db68782bdd0731b59bbf211067710 100644 (file)
@@ -156,8 +156,8 @@ int boot_relocate_fdt(struct lmb *lmb, char **of_flat_tree, ulong *of_size)
        } else {
                of_start =
                    (void *)(ulong) lmb_alloc_base(lmb, of_len, 0x1000,
-                                                  getenv_bootm_mapsize()
-                                                  + getenv_bootm_low());
+                                                  env_get_bootm_mapsize()
+                                                  + env_get_bootm_low());
        }
 
        if (of_start == NULL) {
index 98c0eaa4c70f886a7a53857257c7157981abd582..a058eb85e107bce98c7a155344250cc30f16ef18 100644 (file)
@@ -465,7 +465,7 @@ static int on_loadaddr(const char *name, const char *value, enum env_op op,
 }
 U_BOOT_ENV_CALLBACK(loadaddr, on_loadaddr);
 
-ulong getenv_bootm_low(void)
+ulong env_get_bootm_low(void)
 {
        char *s = env_get("bootm_low");
        if (s) {
@@ -482,7 +482,7 @@ ulong getenv_bootm_low(void)
 #endif
 }
 
-phys_size_t getenv_bootm_size(void)
+phys_size_t env_get_bootm_size(void)
 {
        phys_size_t tmp, size;
        phys_addr_t start;
@@ -509,7 +509,7 @@ phys_size_t getenv_bootm_size(void)
        return size - (tmp - start);
 }
 
-phys_size_t getenv_bootm_mapsize(void)
+phys_size_t env_get_bootm_mapsize(void)
 {
        phys_size_t tmp;
        char *s = env_get("bootm_mapsize");
@@ -521,7 +521,7 @@ phys_size_t getenv_bootm_mapsize(void)
 #if defined(CONFIG_SYS_BOOTMAPSZ)
        return CONFIG_SYS_BOOTMAPSZ;
 #else
-       return getenv_bootm_size();
+       return env_get_bootm_size();
 #endif
 }
 
@@ -1233,7 +1233,7 @@ int boot_ramdisk_high(struct lmb *lmb, ulong rd_data, ulong rd_len,
                if (initrd_high == ~0)
                        initrd_copy_to_ram = 0;
        } else {
-               initrd_high = getenv_bootm_mapsize() + getenv_bootm_low();
+               initrd_high = env_get_bootm_mapsize() + env_get_bootm_low();
        }
 
 
@@ -1506,7 +1506,7 @@ int boot_get_loadable(int argc, char * const argv[], bootm_headers_t *images,
  * @cmd_end: pointer to a ulong variable, will hold cmdline end
  *
  * boot_get_cmdline() allocates space for kernel command line below
* BOOTMAPSZ + getenv_bootm_low() address. If "bootargs" U-Boot environemnt
  * variable is present its contents is copied to allocated kernel
  * command line.
  *
@@ -1520,7 +1520,7 @@ int boot_get_cmdline(struct lmb *lmb, ulong *cmd_start, ulong *cmd_end)
        char *s;
 
        cmdline = (char *)(ulong)lmb_alloc_base(lmb, CONFIG_SYS_BARGSIZE, 0xf,
-                               getenv_bootm_mapsize() + getenv_bootm_low());
+                               env_get_bootm_mapsize() + env_get_bootm_low());
 
        if (cmdline == NULL)
                return -1;
@@ -1547,7 +1547,7 @@ int boot_get_cmdline(struct lmb *lmb, ulong *cmd_start, ulong *cmd_end)
  * @kbd: double pointer to board info data
  *
  * boot_get_kbd() allocates space for kernel copy of board info data below
* BOOTMAPSZ + getenv_bootm_low() address and kernel board info is initialized
  * with the current u-boot board info data.
  *
  * returns:
@@ -1557,7 +1557,7 @@ int boot_get_cmdline(struct lmb *lmb, ulong *cmd_start, ulong *cmd_end)
 int boot_get_kbd(struct lmb *lmb, bd_t **kbd)
 {
        *kbd = (bd_t *)(ulong)lmb_alloc_base(lmb, sizeof(bd_t), 0xf,
-                               getenv_bootm_mapsize() + getenv_bootm_low());
+                               env_get_bootm_mapsize() + env_get_bootm_low());
        if (*kbd == NULL)
                return -1;
 
index 2210c57a64e816ba484d40631631e414874adc86..e9dbedf32680ec05143e63d70cfa335261fafbf2 100644 (file)
@@ -62,8 +62,8 @@ static int is_broadcast(struct in_addr ip)
 
        /* update only when the environment has changed */
        if (env_changed_id != env_id) {
-               netmask = getenv_ip("netmask");
-               our_ip = getenv_ip("ipaddr");
+               netmask = env_get_ip("netmask");
+               our_ip = env_get_ip("ipaddr");
 
                env_changed_id = env_id;
        }
@@ -83,7 +83,7 @@ static int refresh_settings_from_env(void)
        /* update only when the environment has changed */
        if (env_changed_id != env_id) {
                if (env_get("ncip")) {
-                       nc_ip = getenv_ip("ncip");
+                       nc_ip = env_get_ip("ncip");
                        if (!nc_ip.s_addr)
                                return -1;      /* ncip is 0.0.0.0 */
                        p = strchr(env_get("ncip"), ':');
index 71613aa9deb385a4dec2543d95c8d5757741bb67..688d5ab4c8985434288bc090d5797b95462eb96d 100644 (file)
@@ -44,7 +44,7 @@ int env_get_yesno(const char *var)
 /*
  * Look up the variable from the default environment
  */
-char *getenv_default(const char *name)
+char *env_get_default(const char *name)
 {
        char *ret_val;
        unsigned long really_valid = gd->env_valid;
index 85a344fa517f1289c3605c5768bc573eff36b0d1..4b0ddb6bb85b2c709040295b75b702763b0612a6 100644 (file)
@@ -541,7 +541,7 @@ int env_flags_validate(const ENTRY *item, const char *newval, enum env_op op,
                        return 1;
                } else if (item->flags &
                    ENV_FLAGS_VARACCESS_PREVENT_NONDEF_OVERWR) {
-                       const char *defval = getenv_default(name);
+                       const char *defval = env_get_default(name);
 
                        if (defval == NULL)
                                defval = "";
index eb44c9ef4231c47dbdd8e5cd78812524694d2c86..aaed13167123b2bd5a0e8aeb5da2014c82720cdf 100644 (file)
@@ -749,7 +749,7 @@ int zzip(void *dst, unsigned long *lenp, unsigned char *src,
 
 /* lib/net_utils.c */
 #include <net.h>
-static inline struct in_addr getenv_ip(char *var)
+static inline struct in_addr env_get_ip(char *var)
 {
        return string_to_ip(env_get(var));
 }
index a055e3fa890361219917ba51e89aebce11004162..9a4421523555db78d0f86495e0cbeb2b720242dc 100644 (file)
@@ -282,7 +282,7 @@ extern struct hsearch_data env_htab;
 void env_crc_update(void);
 
 /* Look up the variable from the default environment */
-char *getenv_default(const char *name);
+char *env_get_default(const char *name);
 
 /* [re]set to the default environment */
 void set_default_env(const char *s);
index c4fe4cfb8b155fe422980530ead18040920e3fe6..1f4bfda2f3f1a314e3a176ae66a88eb34715250a 100644 (file)
@@ -769,9 +769,9 @@ static inline void image_set_name(image_header_t *hdr, const char *name)
 int image_check_hcrc(const image_header_t *hdr);
 int image_check_dcrc(const image_header_t *hdr);
 #ifndef USE_HOSTCC
-ulong getenv_bootm_low(void);
-phys_size_t getenv_bootm_size(void);
-phys_size_t getenv_bootm_mapsize(void);
+ulong env_get_bootm_low(void);
+phys_size_t env_get_bootm_size(void);
+phys_size_t env_get_bootm_mapsize(void);
 #endif
 void memmove_wd(void *to, void *from, size_t len, ulong chunksz);
 
index a6f908265316d1e009491d8ca8516aa415e8b4cf..455b48f6c720d3694888e3802a0bb52fe7c6ea17 100644 (file)
@@ -834,7 +834,7 @@ void vlan_to_string(ushort x, char *s);
 ushort string_to_vlan(const char *s);
 
 /* read a VLAN id from an environment variable */
-ushort getenv_vlan(char *);
+ushort env_get_vlan(char *);
 
 /* copy a filename (allow for "..." notation, limit length) */
 void copy_filename(char *dst, const char *src, int size);
index dfd240dfbcfd90288de50fdf54c934bbe754549a..31cdef4083a2e7afc183159f9552e9a00564193b 100644 (file)
@@ -104,7 +104,7 @@ static void configure_wait(void)
 
 void link_local_start(void)
 {
-       ip = getenv_ip("llipaddr");
+       ip = env_get_ip("llipaddr");
        if (ip.s_addr != 0 &&
            (ntohl(ip.s_addr) & IN_CLASSB_NET) != LINKLOCAL_ADDR) {
                puts("invalid link address");
@@ -1506,7 +1506,7 @@ int boot_get_loadable(int argc, char * const argv[], bootm_headers_t *images,
  *
  * boot_get_cmdline() allocates space for kernel command line below
- * BOOTMAPSZ + getenv_bootm_low() address. If "bootargs" U-Boot environemnt
+ * BOOTMAPSZ + env_get_bootm_low() address. If "bootargs" U-Boot environemnt
  * variable is present its contents is copied to allocated kernel
  * command line.
@@ -1547,7 +1547,7 @@ int boot_get_cmdline(struct lmb *lmb, ulong *cmd_start, ulong *cmd_end)
  *
  * boot_get_kbd() allocates space for kernel copy of board info data below
- * BOOTMAPSZ + getenv_bootm_low() address and kernel board info is initialized
+ * BOOTMAPSZ + env_get_bootm_low() address and kernel board info is initialized
  * with the current u-boot board info data.
  *
index 0b876913e35fe89a74d02e76348fe515cec1a2d9..4259c9e321d6905efef6ca5abe441e89943eab9f 100644 (file)